@@ -143,7 +143,7 @@ static struct
   /* The context of an associated writer object or NULL.  */
   struct writer_context_s *writer;
 
-  /* A notification handler.  Noet that we current support only one
+  /* A notification handler.  Note that we currently support only one
    * callback per fd.  */
   struct {
     _gpgme_close_notify_handler_t handler;
@@ -410,7 +410,7 @@ reader (void *arg)
               else
                 {
                   /* Check whether the shutdown triggered the error -
-                     no need to to print a warning in this case.  */
+                     no need to print a warning in this case.  */
                   if ( ctx->error_code == WSAECONNABORTED
                        || ctx->error_code == WSAECONNRESET)
                     {
@@ -749,8 +749,8 @@ _gpgme_io_read (int fd, void *buffer, size_t count)
 
 
 /* The writer does use a simple buffering strategy so that we are
-   informed about write errors as soon as possible (i. e. with the the
-   next call to the write function.  */
+   informed about write errors as soon as possible (i.e. with the
+   next call to the write function).  */
 static DWORD CALLBACK
 writer (void *arg)
 {
@@ -1275,7 +1275,7 @@ _gpgme_io_close (int fd)
 
 
 /* Set a close notification callback which is called right after FD
- * has been closed but before its slot (ie. the FD number) is being
+ * has been closed but before its slot (i.e. the FD number) is being
  * released.  The HANDLER may thus use the provided value of the FD
  * but it may not pass it to any I/O functions.  Note: Only the last
  * handler set for an FD is used.  */
@@ -1643,7 +1643,7 @@ _gpgme_io_select (struct io_select_fd_s *fds, size_t nfds, int nonblock)
   int i;
   int any;
   int count;
-  void *dbg_help;
+  void *dbg_help = NULL;
   TRACE_BEG  (DEBUG_SYSIO, "_gpgme_io_select", fds,
 	      "nfds=%u, nonblock=%u", nfds, nonblock);
 
